==> pdfpug-0.4.0.tar.gz: pdfpug-0.4.0/setup.py <==
#  MIT License
#
#  Copyright (C) 2019 Nekhelesh Ramananthan
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
#  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
#  PARTICULAR PURPOSE AND  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
#  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
#  AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
#  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import pathlib

from setuptools import setup

# Current directory path
HERE = pathlib.Path(__file__).parent

# Project's long description
README = (HERE / "README.md").read_text()

setup(
    name="pdfpug",
    version="0.4.0",
    description="Create PDFs from scratch using simple, easy to use APIs",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/krnekhelesh/pdfpug",
    author="Nekhelesh Ramananthan",
    author_email="krnekhelesh@gmail.com",
    python_requires=">3.6.0",
    license="MIT",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Natural Language :: English",
    ],
    packages=["pdfpug", "pdfpug.modules", "pdfpug.common", "pdfpug.layouts"],
    include_package_data=True,
    install_requires=["jinja2", "weasyprint", "pypugjs"],
)

==> pdfpug-0.5.0.tar.gz: pdfpug-0.5.0/setup.py <==
#  MIT License
#
#  Copyright (C) 2019 Nekhelesh Ramananthan
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
#  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
#  PARTICULAR PURPOSE AND  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
#  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
#  AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
#  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import pathlib

from setuptools import setup

# Current directory path
HERE = pathlib.Path(__file__).parent

# Project's long description
README = (HERE / "README.md").read_text()

setup(
    name="pdfpug",
    version="0.5.0",
    description="Create PDFs from scratch using simple, easy to use APIs",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/krnekhelesh/pdfpug",
    author="Nekhelesh Ramananthan",
    author_email="krnekhelesh@gmail.com",
    python_requires=">3.6.0",
    license="MIT",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Natural Language :: English",
    ],
    packages=["pdfpug", "pdfpug.modules", "pdfpug.common", "pdfpug.layouts"],
    include_package_data=True,
    install_requires=["jinja2", "weasyprint", "pypugjs"],
)
